@@ -317,7 +317,207 @@ arv_debug_level_get_type (void)
 	return the_type;
 }
 
-#include "arvgcregister.h"
+#include "arvdomnode.h"
+
+GType
+arv_dom_node_type_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_DOM_NODE_TYPE_ELEMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_ELEMENT_NODE",
+			  "element-node" },
+			{ ARV_DOM_NODE_TYPE_ATTRIBUTE_NODE,
+			  "ARV_DOM_NODE_TYPE_ATTRIBUTE_NODE",
+			  "attribute-node" },
+			{ ARV_DOM_NODE_TYPE_TEXT_NODE,
+			  "ARV_DOM_NODE_TYPE_TEXT_NODE",
+			  "text-node" },
+			{ ARV_DOM_NODE_TYPE_CDATA_SECTION_NODE,
+			  "ARV_DOM_NODE_TYPE_CDATA_SECTION_NODE",
+			  "cdata-section-node" },
+			{ ARV_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE,
+			  "ARV_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE",
+			  "entity-reference-node" },
+			{ ARV_DOM_NODE_TYPE_ENTITY_NODE,
+			  "ARV_DOM_NODE_TYPE_ENTITY_NODE",
+			  "entity-node" },
+			{ ARV_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
+			  "ARV_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE",
+			  "processing-instruction-node" },
+			{ ARV_DOM_NODE_TYPE_COMMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_COMMENT_NODE",
+			  "comment-node" },
+			{ ARV_DOM_NODE_TYPE_DOCUMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_DOCUMENT_NODE",
+			  "document-node" },
+			{ ARV_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE,
+			  "ARV_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE",
+			  "document-type-node" },
+			{ ARV_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE",
+			  "document-fragment-node" },
+			{ ARV_DOM_NODE_TYPE_NOTATION_NODE,
+			  "ARV_DOM_NODE_TYPE_NOTATION_NODE",
+			  "notation-node" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvDomNodeType"),
+				values);
+	}
+	return the_type;
+}
+
+#include "arvgcpropertynode.h"
+
+GType
+arv_gc_property_node_type_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_GC_PROPERTY_NODE_TYPE_UNKNOWN,
+			  "ARV_GC_PROPERTY_NODE_TYPE_UNKNOWN",
+			  "unknown" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_VALUE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_VALUE",
+			  "value" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_ADDRESS,
+			  "ARV_GC_PROPERTY_NODE_TYPE_ADDRESS",
+			  "address" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_DESCRIPTION,
+			  "ARV_GC_PROPERTY_NODE_TYPE_DESCRIPTION",
+			  "description" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_TOOLTIP,
+			  "ARV_GC_PROPERTY_NODE_TYPE_TOOLTIP",
+			  "tooltip" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_DISPLAY_NAME,
+			  "ARV_GC_PROPERTY_NODE_TYPE_DISPLAY_NAME",
+			  "display-name" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_MINIMUM,
+			  "ARV_GC_PROPERTY_NODE_TYPE_MINIMUM",
+			  "minimum" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_MAXIMUM,
+			  "ARV_GC_PROPERTY_NODE_TYPE_MAXIMUM",
+			  "maximum" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_INCREMENT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_INCREMENT",
+			  "increment" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_UNIT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_UNIT",
+			  "unit" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_ON_VALUE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_ON_VALUE",
+			  "on-value" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_OFF_VALUE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_OFF_VALUE",
+			  "off-value" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_LENGTH,
+			  "ARV_GC_PROPERTY_NODE_TYPE_LENGTH",
+			  "length" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_FORMULA,
+			  "ARV_GC_PROPERTY_NODE_TYPE_FORMULA",
+			  "formula" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_FORMULA_TO,
+			  "ARV_GC_PROPERTY_NODE_TYPE_FORMULA_TO",
+			  "formula-to" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_FORMULA_FROM,
+			  "ARV_GC_PROPERTY_NODE_TYPE_FORMULA_FROM",
+			  "formula-from" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_EXPRESSION,
+			  "ARV_GC_PROPERTY_NODE_TYPE_EXPRESSION",
+			  "expression" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_CONSTANT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_CONSTANT",
+			  "constant" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_ACCESS_MODE",
+			  "access-mode" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_CACHABLE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_CACHABLE",
+			  "cachable" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_POLLING_TIME,
+			  "ARV_GC_PROPERTY_NODE_TYPE_POLLING_TIME",
+			  "polling-time" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_ENDIANESS,
+			  "ARV_GC_PROPERTY_NODE_TYPE_ENDIANESS",
+			  "endianess" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_SIGN,
+			  "ARV_GC_PROPERTY_NODE_TYPE_SIGN",
+			  "sign" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_LSB,
+			  "ARV_GC_PROPERTY_NODE_TYPE_LSB",
+			  "lsb" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_MSB,
+			  "ARV_GC_PROPERTY_NODE_TYPE_MSB",
+			  "msb" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_BIT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_BIT",
+			  "bit" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_COMMAND_VALUE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_COMMAND_VALUE",
+			  "command-value" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW",
+			  "p-unknonw" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_FEATURE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_FEATURE",
+			  "p-feature" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_VALUE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_VALUE",
+			  "p-value" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_ADDRESS,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_ADDRESS",
+			  "p-address" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_IS_IMPLEMENTED,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_IS_IMPLEMENTED",
+			  "p-is-implemented" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_IS_AVAILABLE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_IS_AVAILABLE",
+			  "p-is-available" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_MINIMUM,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_MINIMUM",
+			  "p-minimum" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_MAXIMUM,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_MAXIMUM",
+			  "p-maximum" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_INCREMENT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_INCREMENT",
+			  "p-increment" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_INDEX,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_INDEX",
+			  "p-index" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_LENGTH,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_LENGTH",
+			  "p-length" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_PORT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_PORT",
+			  "p-port" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_VARIABLE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_VARIABLE",
+			  "p-variable" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_INVALIDATOR,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_INVALIDATOR",
+			  "p-invalidator" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_COMMAND_VALUE,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_COMMAND_VALUE",
+			  "p-command-value" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvGcPropertyNodeType"),
+				values);
+	}
+	return the_type;
+}
+
+#include "arvgcregisternode.h"
 
 GType
 arv_gc_sign_get_type (void)
@@ -343,32 +543,35 @@ arv_gc_sign_get_type (void)
 }
 
 GType
-arv_gc_register_type_get_type (void)
+arv_gc_register_node_type_get_type (void)
 {
 	static GType the_type = 0;
 
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ ARV_GC_REGISTER_TYPE_REGISTER,
-			  "ARV_GC_REGISTER_TYPE_REGISTER",
+			{ ARV_GC_REGISTER_NODE_TYPE_REGISTER,
+			  "ARV_GC_REGISTER_NODE_TYPE_REGISTER",
 			  "register" },
-			{ ARV_GC_REGISTER_TYPE_INTEGER,
-			  "ARV_GC_REGISTER_TYPE_INTEGER",
+			{ ARV_GC_REGISTER_NODE_TYPE_INTEGER,
+			  "ARV_GC_REGISTER_NODE_TYPE_INTEGER",
 			  "integer" },
-			{ ARV_GC_REGISTER_TYPE_MASKED_INTEGER,
-			  "ARV_GC_REGISTER_TYPE_MASKED_INTEGER",
+			{ ARV_GC_REGISTER_NODE_TYPE_MASKED_INTEGER,
+			  "ARV_GC_REGISTER_NODE_TYPE_MASKED_INTEGER",
 			  "masked-integer" },
-			{ ARV_GC_REGISTER_TYPE_FLOAT,
-			  "ARV_GC_REGISTER_TYPE_FLOAT",
+			{ ARV_GC_REGISTER_NODE_TYPE_FLOAT,
+			  "ARV_GC_REGISTER_NODE_TYPE_FLOAT",
 			  "float" },
-			{ ARV_GC_REGISTER_TYPE_STRING,
-			  "ARV_GC_REGISTER_TYPE_STRING",
+			{ ARV_GC_REGISTER_NODE_TYPE_STRING,
+			  "ARV_GC_REGISTER_NODE_TYPE_STRING",
 			  "string" },
+			{ ARV_GC_REGISTER_NODE_TYPE_STRUCT_REGISTER,
+			  "ARV_GC_REGISTER_NODE_TYPE_STRUCT_REGISTER",
+			  "struct-register" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvGcRegisterType"),
+				g_intern_static_string ("ArvGcRegisterNodeType"),
 				values);
 	}
 	return the_type;
