@@ -22,9 +22,19 @@ integer_test (void)
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node));
 	g_assert_cmpint (v_int64, ==, 1);
 
-	v_string = arv_gc_node_get_value_as_string (node);
+	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node));
 	g_assert_cmpstr (v_string, ==, "1");
 
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node), 2);
+	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, 2);
+
+	node = arv_gc_get_node (genicam, "P_RWInteger");
+	g_assert (ARV_IS_GC_INTEGER_NODE (node));
+
+	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, 2);
+
 	g_object_unref (device);
 }
 
@@ -34,6 +44,7 @@ boolean_test (void)
 	ArvDevice *device;
 	ArvGc *genicam;
 	ArvGcNode *node;
+	ArvGcNode *node_b;
 	gboolean v_boolean;
 	const char *v_string;
 
@@ -49,9 +60,30 @@ boolean_test (void)
 	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node));
 	g_assert_cmpint (v_boolean, ==, TRUE);
 
-	v_string = arv_gc_node_get_value_as_string (node);
+	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node));
 	g_assert_cmpstr (v_string, ==, "true");
 
+	arv_gc_boolean_set_value (ARV_GC_BOOLEAN (node), 0);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node));
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
+	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node));
+	g_assert_cmpstr (v_string, ==, "false");
+
+	node = arv_gc_get_node (genicam, "P_RWBoolean");
+	g_assert (ARV_IS_GC_BOOLEAN (node));
+
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node));
+	g_assert_cmpint (v_boolean, ==, TRUE);
+
+	node_b = arv_gc_get_node (genicam, "RWBooleanValue");
+	g_assert (ARV_IS_GC_INTEGER (node_b));
+
+	arv_gc_integer_set_value (ARV_GC_INTEGER (node_b), 42);
+
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node));
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
 	g_object_unref (device);
 }
 
@@ -76,9 +108,19 @@ float_test (void)
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node));
 	g_assert_cmpfloat (v_double, ==, 0.1);
 
-	v_string = arv_gc_node_get_value_as_string (node);
+	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node));
 	g_assert_cmpstr (v_string, ==, "0.1");
 
+	arv_gc_float_set_value (ARV_GC_FLOAT (node), 0.2);
+	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, 0.2);
+
+	node = arv_gc_get_node (genicam, "P_RWFloat");
+	g_assert (ARV_IS_GC_FLOAT_NODE (node));
+
+	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, 0.2);
+
 	g_object_unref (device);
 }
 
